<?php
/**
 * elggBook theme plugin
 *
 * @package elggBookTheme
 */
 
 elgg_register_event_handler('init', 'system', 'elggbook_init');

function elggbook_init() {
	/**
	 * Customize pages
	 */
	elgg_register_plugin_hook_handler('index', 'system', 'elggbook_index_handler');
	elgg_register_page_handler('profile', 'elggbook_profile_page_handler');
	elgg_register_page_handler('dashboard', 'elggbook_dashboard_handler');
	
	//What a hack!  Overriding groups page handler without blowing away other plugins doing the same
	global $CONFIG, $elggbook_original_groups_page_handler;
	//elggbook_original_groups_page_handler = $CONFIG->pagehandler['groups'];
	elgg_register_page_handler('groups', 'elggbook_groups_page_handler');
	
	/**
	 * Customize menus
	 */
	elgg_unregister_plugin_hook_handler('register', 'menu:river', 'likes_river_menu_setup');
	elgg_unregister_plugin_hook_handler('register', 'menu:entity', 'likes_entity_menu_setup');
	elgg_unregister_plugin_hook_handler('register', 'menu:river', '_elgg_river_menu_setup');
	elgg_unregister_plugin_hook_handler('register', 'menu:entity', '_elgg_entity_menu_setup');
	
	if (!elgg_is_active_plugin('hypeInteractions')) {
		
	//Likes summary bar -- "You, John, and 3 others like this"
	    if (elgg_is_active_plugin('likes')) {
		    elgg_extend_view('river/elements/responses', 'likes/river_footer', 1);
	        elgg_register_plugin_hook_handler('register', 'menu:river', 'my_likes_river_menu_setup', 401);
	        elgg_register_plugin_hook_handler('register', 'menu:entity', 'my_likes_entity_menu_setup', 401);
		    elgg_extend_view('river/elements/responses', 'discussion/river_footer');
	    }	
	}	
	    
	    elgg_register_plugin_hook_handler('register', 'menu:entity', 'elggbook_entity_menu_setup');
	    elgg_register_plugin_hook_handler('register', 'menu:river', 'elggbook_river_menu_handler');
		
	if (elgg_is_active_plugin('hypeWall')) {
	    elgg_unregister_plugin_hook_handler('register', 'menu:entity', '\hypeJunction\Wall\HookHandlers::entityMenuSetup');
	    elgg_unregister_plugin_hook_handler('register', 'menu:river', '\hypeJunction\Wall\HookHandlers::riverMenuSetup');
		elgg_unregister_plugin_hook_handler('register', 'menu:owner_block', '\hypeJunction\Wall\HookHandlers::ownerBlockMenuSetup');
		
		elgg_register_plugin_hook_handler('register', 'menu:entity', 'hypeWall_entityMenuSetup');
		elgg_register_plugin_hook_handler('register', 'menu:river', 'hypeWall_riverMenuSetup');
	}
	
	elgg_register_plugin_hook_handler('register', 'menu:owner_block', 'elggbook_owner_block_menu_handler', 600);
	
	elgg_register_event_handler('pagesetup', 'system', 'elggbook_pagesetup_handler', 1000);
	
	// Register a plugin hook handler for the entity menu
	elgg_register_plugin_hook_handler("register", "menu:owner_block", "elggbook_iconized_menu");
	elgg_register_plugin_hook_handler("register", "menu:site", "elggbook_iconized_menu");
	
	elgg_register_plugin_hook_handler('head', 'page', 'elggbook_setup_head');
	
		elgg_unregister_plugin_hook_handler('output:before', 'layout', 'elgg_views_add_rss_link');
	
	/**
	 * Customize permissions
	 */
	elgg_register_plugin_hook_handler('permissions_check:annotate', 'all', 'elggbook_annotation_permissions_handler');
	elgg_register_plugin_hook_handler('container_permissions_check', 'all', 'elggbook_container_permissions_handler');
	
	/**
	 * Miscellaneous customizations
	 */
	//Small "correction" to groups profile -- brief description makes more sense to come first!
	//elgg_register_plugin_hook_handler('profile:fields', 'group', 'elggbook_group_profile_fields', 1);
	
	//@todo report some of the extra patterns to be included in Elgg core
	elgg_extend_view('elgg.css', 'elggbook.css');
	
	if (elgg_is_active_plugin('market')) {
	    elgg_unextend_view('page/elements/sidebar', 'market/sidebar', 100);		
	}
	
	//elgg_extend_view('js/elgg', 'js/topbar');
	
	//Elgg only includes the search bar in the header by default,
	//but we usually don't show the header when the user is logged in
	if (elgg_is_active_plugin('search')) {
		elgg_extend_view('page/elements/topbar', 'search/search_box');
		elgg_unextend_view('page/elements/header', 'search/search_box');
		
		if (!elgg_is_logged_in()) {
			elgg_unextend_view('page/elements/header', 'search/header');
		}
	}
}

function elggbook_groups_page_handler($page) {
	
	$pages_dir = dirname(__FILE__) . '/pages';

	if (!isset($page[0])) {
		$page[0] = 'all';
	}

	elgg_push_breadcrumb(elgg_echo('groups'), "groups/all");

	$vars = [];
	switch ($page[0]) {
		case 'add':
		case 'all':
		case 'owner':
		case 'search':
			echo elgg_view_resource("groups/{$page[0]}");
			break;
		case 'invitations':
		case 'member':
			echo elgg_view_resource("groups/{$page[0]}", [
				'username' => $page[1],
			]);
			break;
		case 'members':
			$vars['sort'] = elgg_extract('2', $page, 'alpha');
			$vars['guid'] = elgg_extract('1', $page);
			if (elgg_view_exists("resources/groups/members/{$vars['sort']}")) {
				echo elgg_view_resource("groups/members/{$vars['sort']}", $vars);
			} else {
				echo elgg_view_resource('groups/members', $vars);
			}
			break;
		case 'profile':
			// Page owner and context need to be set before elgg_view() is
			// called so they'll be available in the [pagesetup, system] event
			// that is used for registering items for the sidebar menu.
			// @see groups_setup_sidebar_menus()
			elgg_push_context('group_profile');
			elgg_set_page_owner_guid($page[1]);
			require_once "$pages_dir/groups/wall.php";
			break;
		case 'activity':
		case 'edit':
		case 'invite':
		case 'requests':
			echo elgg_view_resource("groups/{$page[0]}", [
				'guid' => $page[1],
			]);
			break;
		case 'info':
			elgg_set_page_owner_guid($page[1]);
			require_once "$pages_dir/groups/info.php";
			break;
		default:
			return false;
	}
	return true;
}

function elggbook_pagesetup_handler() {
	$owner = elgg_get_page_owner_entity();
	
	elgg_unregister_menu_item('footer','powered');

	if (elgg_is_logged_in()) {
		$user = elgg_get_logged_in_user_entity();
		$username = $user->username;
		elgg_register_menu_item('page', array(
			'name' => 'news',
			'text' => '<i class="fa  fa-globe fa-lg" style="color:#bb54d5"></i>' . elgg_echo('newsfeed'),
			'href' => '/dashboard',
			'priority' => 100,
			'contexts' => array('dashboard'),
		));
		
		if (elgg_is_active_plugin('messages')) {
			elgg_register_menu_item('page', array(
				'name' => 'messages',
				'text' => '<i class="fa  fa-envelope fa-lg" style="color:#69bfb0"></i>' . elgg_echo('messages'),
				'href' => "/messages/inbox/$user->username",
				'contexts' => array('dashboard'),
			));
		}
		
		elgg_register_menu_item('page', array(
			'name' => 'friends',
			'text' => '<i class="fa  fa-users fa-lg" style="color:#ff6c8a"></i>' . elgg_echo('friends'),
			'href' => "/friends/$user->username",
			'priority' => 500,
			'contexts' => array('dashboard'),
		));
	
		if ($owner instanceof ElggUser && $owner->guid != $user->guid) {
			
			if (check_entity_relationship($user->guid, 'friend', $owner->guid)) {
				elgg_register_menu_item('extras', array(
					'name' => 'removefriend',
					'text' => '<i class="fa  fa-user-times fa-lg" style="color:#ff6c8a"></i>' . elgg_echo('friend:remove'),
					'href' => "/action/friends/remove?friend=$owner->guid",
					'is_action' => TRUE,
					'contexts' => array('profile'),
				));
			} else {
				elgg_register_menu_item('title', array(
					'name' => 'addfriend',
					'text' => '<i class="fa  fa-user-plus fa-lg" style="color:#ff6c8a"></i>' . elgg_echo('friend:add'),
					'href' => "/action/friends/add?friend=$owner->guid",
					'is_action' => TRUE,
					'link_class' => 'elgg-button elgg-button-special',
					'contexts' => array('profile'),
					'priority' => 1,
				));
			}
			
			if (elgg_is_active_plugin('messages')) {
				elgg_register_menu_item('title', array(
					'name' => 'message',
					'text' => '<i class="fa  fa-evelope fa-lg" style="color:#69bfb0"></i>' . elgg_echo('messages:message'),
					'href' => "/messages/compose?send_to=$owner->guid",
					'link_class' => 'elgg-button elgg-button-info',
					'contexts' => array('profile'),
				));
			}
		}
		
		if ($owner->guid == $user->guid) {
			elgg_register_menu_item('title', array(
				'name' => 'editprofile',
				'href' => "/profile/$user->username/edit",
				'text' => elgg_echo('profile:edit'),
				'link_class' => 'elgg-button elgg-button-info',
				'contexts' => array('profile'),
			));
			elgg_register_menu_item('title', array(
				'name' => 'editavatar',
				'href' => "/avatar/edit/{$user->username}",
				'text' => elgg_echo('avatar:edit'),
				'link_class' => 'elgg-button elgg-button-info',
				'contexts' => array('profile'),
			));
		}

		if (elgg_is_active_plugin('groups')) {
            $dbprefix = elgg_get_config('dbprefix');

            $groups  = elgg_get_entities_from_relationship(array(
                'type' => 'group',
                'owner_guid' => $owner->guid,
                'limit' => 4,
                'full_view' => false,
                'joins' => array("JOIN {$dbprefix}groups_entity ge ON e.guid = ge.guid"),
                'order_by' => 'ge.name asc',
            ));
			
			if(!empty($groups)) { foreach ($groups as $group) {
				elgg_register_menu_item('page', array(
					'section' => 'groups',
					'name' => "group-$group->guid",
					'text' => elgg_view_entity_icon($group, 'tiny', array('href' => false,)) . $group->name,
					'href' => $group->getURL(),
					'contexts' => array('dashboard'),
				));
			}}
			
			elgg_register_menu_item('page', array(
				'name' => 'groups-add',
				'section' => 'groups',
				'text' => '<i class="fa  fa-circle-o-notch fa-lg" style="color:#6cdb01"></i>' . elgg_echo('groups:add'),
				'href' => "/groups/add",
				'contexts' => array('dashboard'),
				'priority' => 499,
			));
			
			elgg_register_menu_item('page', array(
				'section' => 'groups',
				'name' => 'groups',
				'text' => '<i class="fa  fa-hand-o-right fa-lg" style="color:#b60000"></i>' . elgg_echo('see:all'),
				'href' => "/groups/member/$user->username",
				'contexts' => array('dashboard'),
				'priority' => 500,
			));
		}			
		
		if (elgg_is_active_plugin('bookmarks')) {
			elgg_register_menu_item('page', array(
				'section' => 'more',
				'name' => 'bookmarks',
				'text' => '<i class="fa  fa-link fa-lg" style="color:#ff4703"></i>' . elgg_echo('bookmarks'),	
				'href' => "/bookmarks/all",
				'contexts' => array('dashboard'),
			));
		}
		
		if (elgg_is_active_plugin('blog')) {
			elgg_register_menu_item('page', array(
				'section' => 'more',	
				'name' => 'blog',
				'text' => '<i class="fa  fa-bold fa-lg" style="color:#f580a7"></i>' . elgg_echo('blog'),
				'href' => "/blog/all",
				'contexts' => array('dashboard'),
			));
		}
		
		if (elgg_is_active_plugin('pages')) {
			elgg_register_menu_item('page', array(
				'section' => 'more',	
				'name' => 'pages',
				'text' => '<i class="fa  fa-list-alt fa-lg" style="color:#50C28C"></i>' . elgg_echo('pages'),
				'href' => "/pages/all",
				'contexts' => array('dashboard'),
			));
		}
		
		if (elgg_is_active_plugin('file')) {
			elgg_register_menu_item('page', array(
				'section' => 'more',	
				'name' => 'files',
				'text' => '<i class="fa  fa-paperclip fa-lg" style="color:#50C28C"></i>' . elgg_echo('files'),
				'href' => "/file/all",
				'contexts' => array('dashboard'),
			));
		}

		if (elgg_is_active_plugin('thewire')) {
			elgg_register_menu_item('page', array(
				'section' => 'more',
				'name' => 'thewire',
				'text' => '<i class="fa  fa-pencil-square fa-lg" style="color:#50C28C"></i>' . elgg_echo('Wire'),
				'href' => "/thewire/all",
				'contexts' => array('dashboard'),
			));
		}
		
		$address = urlencode(current_page_url());
		
		if (elgg_is_active_plugin('bookmarks')) {
			elgg_register_menu_item('extras', array(
				'name' => 'bookmark',
				'text' => '<i class="fa  fa-thumb-tack fa-lg" style="color:#ff4703"></i>' . elgg_echo('bookmarks:this'),
				'href' => "bookmarks/add/$user_guid?address=$address",
				'title' => elgg_echo('bookmarks:this'),
				'rel' => 'nofollow',
			));
		}
		
	elgg_register_menu_item('extras', array(
		'name' => 'rss',
		'text' => '<i class="fa  fa-rss fa-lg" style="color:#50C28C"></i>' . elgg_echo("rss:subscribe"),
		'href' => '?view=rss',
	));
		
		if (elgg_is_active_plugin('reportedcontent')) {
			elgg_unregister_menu_item('extras', 'report_this');
				
			elgg_register_menu_item('extras', array(
			    'name' => 'report_this',
			    'href' => 'reportedcontent/add',
			    'title' => elgg_echo('reportedcontent:this:tooltip'),
			    'text' => '<i class="fa  fa-warning fa-lg" style="color:#50C28C"></i>' . elgg_echo('reportedcontent:this'),
			    'priority' => 500,
			    'link_class' => 'elgg-lightbox',
			));
		}
		
		/**
		 * TOPBAR customizations
		 */
		//Want our logo present, not Elgg's
		$site = elgg_get_site_entity();
		elgg_unregister_menu_item('topbar', 'elgg_logo');
		elgg_register_menu_item('topbar', array(
			'href' => '/',
			'name' => 'logo',
			'priority' => 1,
			'text' => "<h1 id=\"elggbook-topbar-logo\">$site->name</h1>",
		));
		
		//elgg_unregister_menu_item('topbar','messages');
		elgg_unregister_plugin_hook_handler('register', 'menu:topbar', 'messages_register_topbar');
		$text = '<i class="fa  fa-envelope fa-lg" style="color:#69bfb0"></i>';
		$tooltip = elgg_echo("messages");
		// get unread messages
		$num_messages = (int)messages_count_unread();
		if ($num_messages != 0) {
			$text .= "<span class=\"elgg-topbar-new\">$num_messages</span>";
			$tooltip .= ": ".elgg_echo("messages:unreadcount", array($num_messages));
		}

		elgg_register_menu_item('topbar', array(
			'name' => 'messages',
			'href' => "messages/inbox/$username",
			'text' => $text,
			//'section' => 'alt',
			'priority' => 100,
			'title' => $tooltip,
		));

		$text = '<i class="fa  fa-users fa-lg" style="color:#ff6c8a"></i>';
		$tooltip = elgg_echo("friends");
		$href = "/friends/".$username;
		if (elgg_is_active_plugin('friend_request')) {
			elgg_unregister_menu_item('topbar', 'friend_request');
			$options = array(
				"type" => "user",
				"count" => true,
				"relationship" => "friendrequest",
				"relationship_guid" => $user->getGUID(),
				"inverse_relationship" => true
			);
			
			$count = elgg_get_entities_from_relationship($options);
			if (!empty($count)) {
				$text .= "<span class=\"elgg-topbar-new\">$count</span>";
				$tooltip = elgg_echo("friend_request:menu").": ".$count;
				$href = "friend_request/" . $username;
			}
		}

		elgg_unregister_menu_item('topbar', 'friends');
		elgg_register_menu_item('topbar', array(
			'href' => $href,
			'name' => 'friends',
			'text' =>  $text,
			//'section' => 'alt',
			'priority' => 200,
			'title' => $tooltip,
		));
		
		elgg_register_menu_item('topbar', array(
			'href' => '/dashboard',
			'name' => 'home',
			'priority' => 1,
			'section' => 'alt',
			'text' => '<i class="fa  fa-home fa-lg" style="color:#c7fff5;"></i>' . elgg_echo('home'),
		));
		
		if (elgg_is_active_plugin('profile')) {
			elgg_unregister_menu_item('topbar', 'profile');
			elgg_register_menu_item('topbar', array(
				'name' => 'profile',
				'section' => 'alt',
				'text' => "<img src=\"{$user->getIconURL('topbar')}\" class=\"elgg-icon elgg-inline-block\" alt=\"$user->name\"/> " . $user->name,
				'href' => "/profile/$user->username",
				'priority' => 2,
			));
		}

		elgg_register_menu_item('topbar', array(
			'name' => 'account',
			'href' => "#",
			'priority' => 1000,
			'section' => 'alt',
			'text' => '',
			'link_class' => 'elgg-topbar-dropdown',
		));

		if (elgg_is_active_plugin('dashboard')) {
			$item = elgg_unregister_menu_item('topbar', 'dashboard');
		}
		
		$item = elgg_get_menu_item('topbar', 'usersettings');
		if ($item) {
			$item->setParentName('account');
			$item->setText('<i class="fa  fa-cogs fa-lg" style="color:#02bfff"></i>' . elgg_echo('settings'));
			$item->setPriority(103);
		}

		$item = elgg_get_menu_item('topbar', 'logout');
		if ($item) {
			$item->setParentName('account');
			$item->setText('<i class="fa  fa-sign-out fa-lg" style="color:#50C28C"></i>' . elgg_echo('logout'));
			$item->setPriority(104);
		}

		$item = elgg_get_menu_item('topbar', 'administration');
		if ($item) {
			$item->setParentName('account');
			$item->setText('<i class="fa  fa-cog fa-lg" style="color:#fbce60"></i>' . elgg_echo('admin'));
			$item->setPriority(101);
		}

		if (elgg_is_active_plugin('site_notifications')) {
			$item = elgg_get_menu_item('topbar', 'site_notifications');
			if ($item) {
				$item->setParentName('account');
				$item->setText('<i class="fa  fa-flag fa-lg" style="color:#27a2a7"></i>' . elgg_echo('site_notifications:topbar'));
				$item->setPriority(102);
			}
		}
	}
		
    elgg_register_menu_item('footer', ElggMenuItem::factory(array(
		'name' => 'powered',
		'text' => 'Powered by Hypenia & Elgg',
		'href' => 'https://developer.hypenia.com',
		'title' => 'elggbook Premium',
		'section' => 'alt',
	)));
}

/**
 * Add icons to the ownerblock menu
 */
function elggbook_iconized_menu($hook, $type, $items, $params) {

	$name_to_icon = array(
		"activity" => '<i class="fa  fa-globe fa-lg"></i>',
		"bookmarks" => '<i class="fa  fa-link fa-lg"></i>',
		"thewire" => '<i class="fa  fa-pencil-square fa-lg"></i>',
		"groups" => '<i class="fa  fa-circle-o fa-lg"></i>',
		"file" => '<i class="fa  fa-paperclip fa-lg"></i>',
		"pages" => '<i class="fa  fa-list-alt fa-lg"></i>',
		"members" => '<i class="fa  fa-user fa-lg"></i>',
		"blog" => '<i class="fa  fa-bold fa-lg"></i>',
		"videolist" => '<i class="fa  fa-video-camera fa-lg"></i>',
		"event_manager" => '<i class="fa  fa-calendar-o fa-lg"></i>',
		'event_calendar' => '<i class="fa  fa-calendar-o fa-lg"></i>',
		"poll" => '<i class="fa  fa-check-square fa-lg"></i>',
		"photos" => '<i class="fa  fa-camera fa-lg"></i>',
		"FAQ" => '<i class="fa  fa-question-circle-o fa-lg"></i>',
		"scheduling" => '<i class="fa  fa-calendar-check-o fa-lg"></i>',
		"etherpad" => '<i class="fa  fa-wpforms fa-lg"></i>',
		"discussion" => '<i class="fa  fa-stack-exchange fa-lg"></i>',
		"translation_editor" => '<i class="fa  fa-language fa-lg"></i>',
		"dashboard" => '<i class="fa  fa-dashboard fa-lg"></i>',
		"groups-add" => '<i class="fa  fa-circle-o-notch fa-lg"></i>',
		"groups:member" => '<i class="fa  fa-circle fa-lg"></i>',
		'izap_videos' => '<i class="fa  fa-film fa-lg"></i>',
		'videos' => '<i class="fa  fa-film fa-lg"></i>',
		'video' => '<i class="fa  fa-film fa-lg"></i>',
		'videolist' => '<i class="fa  fa-play fa-lg"></i>',
		'photo_albums' => '<i class="fa  fa-image fa-lg"></i>',
		'gallery' => '<i class="fa  fa-camera fa-lg"></i>',
		'wall' => '<i class="fa  fa-building fa-lg"></i>',
		'group:albums' => '<i class="fa  fa-image fa-lg"></i>',
		'user:albums' => '<i class="fa  fa-image fa-lg"></i>',
		'images' => '<i class="fa  fa-image fa-lg"></i>',
		'market' => '<i class="fa  fa-shopping-cart fa-lg"></i>',
		'events' => '<i class="fa  fa-calendar fa-lg"></i>',
	);
	$icon_name = "pippo"; //set a fake default
	foreach ($items as $key => $item) {

		$icon_name = $name_to_icon[$item->getName()];
		$item->setText(elgg_view_icon($icon_name) . $item->getText());
	}

	return $items;
}

function elggbook_dashboard_handler() {
	require_once dirname(__FILE__) . '/pages/dashboard.php';
	return true;
}

function elggbook_index_handler() {
	if (elgg_is_logged_in()) {
		forward('/dashboard');
	}
}

function elggbook_container_permissions_handler($hook, $type, $result, $params) {
	$container = $params['container'];
	$subtype = $params['subtype'];
	
	if ($container instanceof ElggGroup) {
		if ($subtype == 'thewire') {
			return false;
		}
	}
}

function elggbook_annotation_permissions_handler($hook, $type, $result, $params) {
	$entity = $params['entity'];
	$user = $params['user'];
	$annotation_name = $params['annotation_name'];
	
	//Users should not be able to post on their own message board
	if ($annotation_name == 'messageboard' && $user->guid == $entity->guid) {
		return false;
	}
	
	//No "commenting" on users, must use messageboard
	if ($annotation_name == 'generic_comment' && $entity instanceof ElggUser) {
		return false;
	}
	
	//No "commenting" on forum topics, must use special "reply" annotation
	if ($annotation_name == 'generic_comment' && elgg_instanceof($entity, 'object', 'groupforumtopic')) {
		return false;
	}
	
	if ($annotation_name == 'generic_comment' && elgg_instanceof($entity, 'object', 'discussion_reply')) {
		return false;
	}
	
	if ($annotation_name == 'generic_comment' && elgg_instanceof($entity, 'object', 'thewire')) {
		return false;
	}
	
	//Definitely should be able to "like" a forum topic!
	if ($annotation_name == 'likes' && elgg_instanceof($entity, 'object', 'groupforumtopic')) {
		return true;
	}
	
	if ($annotation_name == 'group_topic_post' && !elgg_instanceof($entity, 'object', 'groupforumtopic')) {
		return false;
	}
}

function elggbook_owner_block_menu_handler($hook, $type, $items, $params) {
	$owner = elgg_get_page_owner_entity();
	
	if ($owner instanceof ElggGroup) {
		$items['info'] = ElggMenuItem::factory(array(
			'name' => 'info', 
			'text' => '<i class="fa  fa-info-circle fa-lg" style="color:#761cc9"></i>' . elgg_echo('profile:info'), 
			'href' => "/groups/info/$owner->guid/" . elgg_get_friendly_title($owner->name),
			'priority' => 2,
		));
		
		$items['profile'] = ElggMenuItem::factory(array(
			'name' => 'profile',
			'text' => '<i class="fa  fa-building fa-lg" style="color:#b42222"></i>' . elgg_echo('profile:wall'),
			'href' => "/groups/profile/$owner->guid/" . elgg_get_friendly_title($owner->name),
			'priority' => 1,
		));
	}
	
	if ($owner instanceof ElggUser) {
		$items['info'] = ElggMenuItem::factory(array(
			'name' => 'info', 
			'text' => '<i class="fa  fa-info-circle fa-lg" style="color:#761cc9"></i>' . elgg_echo('profile:info'), 
			'href' => "/profile/$owner->username/info",
			'priority' => 2,
		));
		
		$items['profile'] = ElggMenuItem::factory(array(
			'name' => 'profile',
			'text' => '<i class="fa  fa-building fa-lg" style="color:#b42222"></i>' . elgg_echo('profile:wall'),
			'href' => "/profile/$owner->username",
			'priority' => 1,
		));
		
		$items['friends'] = ElggMenuItem::factory(array(
			'name' => 'friends',	
			'text' => '<i class="fa  fa-users fa-lg" style="color:#50C28C"></i>' . elgg_echo('friends'),
			'href' => "/friends/$owner->username"
		));
	}
	
	$top_level_pages = elgg_get_entities(array(
		'type' => 'object',
		'subtype' => 'page_top',
		'container_guid' => $owner->guid,
		'limit' => 0,
	));
	
	if(is_array($top_level_pages)) {
	    foreach ($top_level_pages as $page) {
		    $items["pages-$page->guid"] = ElggMenuItem::factory(array(
			    'name' => "pages-$page->guid",
			    'href' => $page->getURL(),
			    'text' => '<i class="fa  fa-list-alt fa-lg" style="color:#50C28C"></i>' . elgg_view('output/text', array('value' => $page->title)),
		    ));		
	    }
	}
	
	return $items;
	
}

/**
 * Add likes to entity menu at end of the menu
 */
function my_likes_entity_menu_setup($hook, $type, $return, $params) {
	if (elgg_in_context('widgets')) {
		return $return;
	}

	$entity = $params['entity'];
	/* @var ElggEntity $entity */

	if ($entity->canAnnotate(0, 'likes')) {
		$hasLiked = \Elgg\Likes\DataService::instance()->currentUserLikesEntity($entity->guid);
		
		// Always register both. That makes it super easy to toggle with javascript
		$return[] = ElggMenuItem::factory(array(
			'name' => 'likes',
			'href' => elgg_add_action_tokens_to_url("/action/likes/add?guid={$entity->guid}"),
			'text' => '<i class="fa fa-thumbs-o-up fa-lg"></i>',
			'title' => elgg_echo('likes:likethis'),
			'item_class' => $hasLiked ? 'hidden' : '',
			'priority' => 100,
		));
		
		$return[] = ElggMenuItem::factory(array(
			'name' => 'unlike',
			'href' => elgg_add_action_tokens_to_url("/action/likes/delete?guid={$entity->guid}"),
			'text' => '<i class="fa  fa-thumbs-up fa-lg" style="color:#50C28C"></i>',
			'title' => elgg_echo('likes:remove'),
			'item_class' => $hasLiked ? '' : 'hidden',
			'priority' => 100,
		));
	}
	
	// likes count
	$count = elgg_view('likes/count', array('entity' => $entity));
	if ($count) {
		$options = array(
			'name' => 'likes_count',
			'text' => $count,
			'href' => false,
			'priority' => 101,
		);
		$return[] = ElggMenuItem::factory($options);
	}

	return $return;
}

/**
 * Add a like button to river actions
 */
function my_likes_river_menu_setup($hook, $type, $return, $params) {
	if (!elgg_is_logged_in() || elgg_in_context('widgets')) {
		return;
	}

	$item = $params['item'];
	/* @var ElggRiverItem $item */

	// only like group creation #3958
	//if ($item->type == "group" && $item->view != "river/group/create") {
		//return;
	//}

	// don't like users #4116
	if ($item->type == "user") {
		return;
	}

	if ($item->annotation_id != 0) {
		return;
	}

	$object = $item->getObjectEntity();
	if (!$object || !$object->canAnnotate(0, 'likes')) {
		return;
	}

	$hasLiked = \Elgg\Likes\DataService::instance()->currentUserLikesEntity($object->guid);

	// Always register both. That makes it super easy to toggle with javascript
	$return[] = ElggMenuItem::factory(array(
		'name' => 'likes',
		'href' => elgg_add_action_tokens_to_url("/action/likes/add?guid={$object->guid}"),
		'text' => '<i class="fa fa-thumbs-o-up fa-lg"></i>',
		'title' => elgg_echo('likes:likethis'),
		'item_class' => $hasLiked ? 'hidden' : '',
		'priority' => 100,
	));
	$return[] = ElggMenuItem::factory(array(
		'name' => 'unlike',
		'href' => elgg_add_action_tokens_to_url("/action/likes/delete?guid={$object->guid}"),
		'text' => '<i class="fa  fa-thumbs-up fa-lg" style="color:#50C28C"></i>',
		'title' => elgg_echo('likes:remove'),
		'item_class' => $hasLiked ? '' : 'hidden',
		'priority' => 100,
	));

	return $return;
}

/**
 * Entity menu is list of links and info on any entity
 * @access private
 */
function elggbook_entity_menu_setup($hook, $type, $return, $params) {
	if (elgg_in_context('widgets')) {
		return $return;
	}
	
	$entity = $params['entity'];
	/* @var \ElggEntity $entity */
	$handler = elgg_extract('handler', $params, false);

	// access
	if (elgg_is_logged_in()) {
		$access = elgg_view('output/access', array('entity' => $entity));
		$options = array(
			'name' => 'access',
			'text' => $access,
			'href' => false,
			'priority' => 100,
		);
		$return[] = \ElggMenuItem::factory($options);
	}
	
	if ($entity->canEdit() && $handler) {
		// edit link
		$options = array(
			'name' => 'edit',
			'text' => '<i class="fa fa-edit fa-lg"></i>',
			'title' => elgg_echo('edit:this'),
			'href' => "$handler/edit/{$entity->getGUID()}",
			'priority' => 200,
		);
		$return[] = \ElggMenuItem::factory($options);

		// delete link
		$options = array(
			'name' => 'delete',
			'text' => '<i class="fa fa-trash-o fa-lg"></i>',
			'title' => elgg_echo('delete:this'),
			'href' => "action/$handler/delete?guid={$entity->getGUID()}",
			'confirm' => elgg_echo('deleteconfirm'),
			'priority' => 300,
		);
		$return[] = \ElggMenuItem::factory($options);
	}

	return $return;
}

function elggbook_river_menu_handler($hook, $type, $return, $params) {
	
	$item = $params['item'];
	$object = $item->getObjectEntity();
	
    if (!elgg_in_context('widgets') && !$item->annotation_id && $object instanceof ElggEntity) {
		if ($object instanceof ElggUser && !$object->isFriend() && $object->guid != $user->guid) {
			$options = array(
				'name' => 'addfriend',
				'href' => "/action/friends/add?friend=$object->guid",
				'text' => elgg_echo('friend:user:add', array($object->name)),
				'is_action' => TRUE,
			);
			$return[] = \ElggMenuItem::factory($options);
		}
		
		if (elgg_instanceof($object, 'object', 'groupforumtopic')) {
			$options = array(
				'name' => 'reply',
				'href' => "#groups-reply-$object->guid",
				'title' => elgg_echo('reply:this'),
				'text' => elgg_echo('reply'),
			);
			$return[] = \ElggMenuItem::factory($options);
		}
	}
	if (elgg_is_logged_in() && elgg_is_admin_logged_in()) {		
		$options = array(
			'name' => 'delete',
			'href' => elgg_add_action_tokens_to_url("action/river/delete?id=$item->id"),
			'text' => '<i class="fa fa-trash-o fa-lg"></i>',
			'title' => elgg_echo('river:delete'),
			'confirm' => elgg_echo('deleteconfirm'),
			'priority' => 300,
			'item_class' => 'align-right',
		);
		$return[] = \ElggMenuItem::factory($options);
	}

	return $return;
}

/**
 * Add actions to the wall post menu
 *
 * @param string $hook   Equals 'register'
 * @param string $type   Equals 'menu:entity'
 * @param array  $return Current menu
 * @param array  $params Additional params
 * @return array Updated menu
 */
function hypeWall_entityMenuSetup($hook, $type, $return, $params) {

	$entity = elgg_extract('entity', $params);
	if (!$entity instanceof Post) {
		return $return;
	}

	$logged_in = elgg_get_logged_in_user_entity();
	if (check_entity_relationship($logged_in->guid, 'tagged_in', $entity->guid)) {
		$return[] = ElggMenuItem::factory(array(
			'name' => 'remove_tag',
			'text' => elgg_echo('wall:remove_tag'),
			'title' => elgg_echo('wall:remove_tag'),
			'priority' => 800,
			'href' => "action/wall/remove_tag?guid=$entity->guid",
			'is_action' => true,
		));
	}

	if ($entity->canEdit()) {
		if (elgg_instanceof($entity, 'object', 'hjwall')) {
			$action = "action/wall/delete?guid=$entity->guid";
		} else if (elgg_instanceof($entity, 'object', 'thewire')) {
			$action = "action/thewire/delete?guid=$entity->guid";
		}
		if ($action) {
			$return[] = ElggMenuItem::factory(array(
				'name' => 'delete',
				'text' => '<i class="fa fa-trash-o fa-lg"></i>',
				'title' => elgg_echo('wall:delete'),
				'priority' => 900,
				'href' => $action,
				'is_action' => true,
				'confirm' => true,
			));
		}
	}
	if ($params['handler'] == 'wall') {
		foreach ($return as $key => $item) {
			if ($item instanceof ElggMenuItem && $item->getName() == 'edit') {
				unset($return[$key]);
			}
		}
	}
	return $return;
}

/**
 * Allow users to delete and remove tags from the river
 *
 * @param string $hook   Equals 'register'
 * @param string $type   Equals 'menu:river'
 * @param array  $return Current menu
 * @param array  $params Additional params
 * @return array Updated menu
 */
function hypeWall_riverMenuSetup($hook, $type, $return, $params) {

	$item = elgg_extract('item', $params);
	if (!($item instanceof ElggRiverItem)) {
		return $return;
	}
	$object = $item->getObjectEntity();

	if (!$object instanceof Post) {
		$logged_in = elgg_get_logged_in_user_entity();
		if (check_entity_relationship($logged_in->guid, 'tagged_in', $object->guid)) {
			$return[] = ElggMenuItem::factory(array(
				'name' => 'remove_tag',
				'text' => elgg_echo('wall:remove_tag'),
				'title' => elgg_echo('wall:remove_tag'),
				'priority' => 800,
				'href' => "action/wall/remove_tag?guid=$object->guid",
				'is_action' => true,
			));
		}
	}

	if ($object->canEdit()) {
		if (elgg_instanceof($object, 'object', 'hjwall')) {
			$action = "action/wall/delete?guid=$object->guid";
		} else if (elgg_instanceof($object, 'object', 'thewire')) {
			$action = "action/thewire/delete?guid=$object->guid";
		}
		if ($action) {
			$return[] = ElggMenuItem::factory(array(
				'name' => 'delete',
				'text' => '<i class="fa fa-trash-o fa-lg"></i>',
				'title' => elgg_echo('wall:delete'),
				'priority' => 900,
				'href' => $action,
				'is_action' => true,
				'confirm' => true,
			));
		}
	}
	return $return;
}

/**
 * Profile page handler
 *
 * @param array $page Array of page elements, forwarded by the page handling mechanism
 */
function elggbook_profile_page_handler($page) {
	if (isset($page[0])) {
		$username = $page[0];
		$user = get_user_by_username($username);
		elgg_set_page_owner_guid($user->guid);
	} elseif (elgg_is_logged_in()) {
		forward(elgg_get_logged_in_user_entity()->getURL());
	}

	// short circuit if invalid or banned username
	if (!$user || ($user->isBanned() && !elgg_is_admin_logged_in())) {
		register_error(elgg_echo('profile:notfound'));
		forward();
	}

	$action = NULL;
	if (isset($page[1])) {
		$action = $page[1];
	}

	if ($action == 'edit') {
		// use the core profile edit page
		echo elgg_view_resource('profile/edit');
		return true;
	}

	switch ($action) {
		
		case 'info':
			require dirname(__FILE__) . '/pages/profile/info.php';
			break;
			
		case 'wall':
			require dirname(__FILE__) . '/pages/profile/wall.php';
			break;
			
		default:
			if (elgg_is_logged_in()) {
				require dirname(__FILE__) . '/pages/profile/wall.php';
			} else {
				require dirname(__FILE__) . '/pages/profile/info.php';
			}
			break;
	}
	
	return true;
}

/**
 * Register items for the html head
 *
 * @param string $hook Hook name ('head')
 * @param string $type Hook type ('page')
 * @param array  $data Array of items for head
 * @return array
 */
function elggbook_setup_head($hook, $type, $data) {
	$data['metas']['viewport'] = array(
		'name' => 'viewport',
		'content' => 'width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0',
	);
	$data['links']['apple-touch-icon'] = array(
		'rel' => 'apple-touch-icon',
		'href' => elgg_get_simplecache_url('elggbook/favicon-128.png'),
	);
	$data['links']['icon-ico'] = array(
		'rel' => 'icon',
		'href' => elgg_get_simplecache_url('elggbook/favicon.ico'),
	);
	$data['links']['icon-16'] = array(
		'rel' => 'icon',
		'sizes' => '16x16',
		'type' => 'image/png',
		'href' => elgg_get_simplecache_url('elggbook/favicon-16.png'),
	);
	$data['links']['icon-32'] = array(
		'rel' => 'icon',
		'sizes' => '32x32',
		'type' => 'image/png',
		'href' => elgg_get_simplecache_url('elggbook/favicon-32.png'),
	);
	$data['links']['icon-64'] = array(
		'rel' => 'icon',
		'sizes' => '64x64',
		'type' => 'image/png',
		'href' => elgg_get_simplecache_url('elggbook/favicon-64.png'),
	);
	$data['links']['icon-128'] = array(
		'rel' => 'icon',
		'sizes' => '128x128',
		'type' => 'image/png',
		'href' => elgg_get_simplecache_url('elggbook/favicon-128.png'),
	);
	return $data;
}
